# MM-VGAE
用于代谢组和空间转录组分析的多模态图变分自编码器。

## 安装
`pip install MetabolicMMVGAE.`

## 运行
conda activate fjj
cd codetest
python MMMVGAE.py ^
--root simu ^
--output_root simu ^
--sample simu ^
--datatype single_cell ^
--epochs 100 ^
--gamma 2.0 ^
--n_clusters_range 10 ^
--seed 2026
